@@ -3,7 +3,7 @@ package Protocol::Dqlite;
 use strict;
 use warnings;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_90';
 
 # https://dqlite.io/docs/protocol
 # https://github.com/canonical/dqlite/blob/master/src/request.h
@@ -36,7 +36,7 @@ Protocol::Dqlite - L<Dqlite|https://dqlite.io> in Perl
         last if $msg isa Protocol::Dqlite::Response::WELCOME;
 
         # An unexpected response. Better bail out …
-	#
+        #
         require Data::Dumper;
         die Data::Dumper::Dumper($msg);
     }
@@ -369,7 +369,7 @@ sub request {
 
 =head2 $obj = I<CLASS>->new()
 
-Instantes I<CLASS>.
+Instantiates I<CLASS>.
 
 =cut
 
@@ -598,7 +598,7 @@ package Protocol::Dqlite::Response;
 
 =head1 RESPONSE CLASSES
 
-All of the below subclass C<Protocol::Dqlite::Response>.
+All of the below extend C<Protocol::Dqlite::Response>.
 They expose various accessors as documented below:
 
 =over
@@ -717,7 +717,8 @@ package Protocol::Dqlite::Response::ROWS;
 
 =item * C<rows_count()>
 
-=item * C<row_types()>, C<row_data()> - need an index, max=(C<rows_count()>-1)
+=item * C<row_types()>, C<row_data()> - these need an index,
+max=(C<rows_count()>-1)
 
 =back
 
@@ -730,13 +731,13 @@ sub column_names { @{ $_[0][1] } }
 sub rows_count { 0 + @{ $_[0][2] } }
 
 sub row_types {
-	my $which = Protocol::Dqlite::Response::SERVERS::_get_which($_[1]);
-	@{ $_[0][2][$which][0] }
+    my $which = Protocol::Dqlite::Response::SERVERS::_get_which($_[1]);
+    @{ $_[0][2][$which][0] }
 }
 
 sub row_data {
-	my $which = Protocol::Dqlite::Response::SERVERS::_get_which($_[1]);
-	@{ $_[0][2][$which][1] }
+    my $which = Protocol::Dqlite::Response::SERVERS::_get_which($_[1]);
+    @{ $_[0][2][$which][1] }
 }
 
 package Protocol::Dqlite::Response::EMPTY;
@@ -770,7 +771,7 @@ sub content {
     Carp::croak("Need name") if !defined $name || !length $name;
     for (my $i=0; $i < @_; $i += 2) {
         next if $_[0][$i] ne $name;
-	return $_[0][1 + $i];
+    return $_[0][1 + $i];
     }
 
     Carp::croak("No file named “$name”");
